==> MuSE-0.5.tar.gz: MuSE-0.5/gui_channel.cpp <==
#include "gui_channel.h"
#include "gui_callbacks.h"
#include "gui_pixmaps.h"
#include <iostream.h>

GuiChannel::GuiChannel(int x, int y, char *label, int z) {
  id =z;

  { Fl_Group* o = main_group = new Fl_Group(x, y, 225, 185, label);
      o->box(FL_UP_BOX);
      o->color(15);
      o->labeltype(FL_ENGRAVED_LABEL);
      o->labelsize(12);
      o->align(FL_ALIGN_TOP_LEFT);
      o->user_data((void*)(this));
      { Fl_Button* o = stepback_button = new Fl_Button(x+12, y+58, 14, 13, "@|<");
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(48);
	o->labeltype(FL_SYMBOL_LABEL);
	o->labelcolor(46);
	o->callback(cb_set_channel_minus, (void *) &id);
      }
//        { Fl_Button* o = play_rev_button = new Fl_Button(x+90, y+13, 15, 15);
//          o->box(FL_FLAT_BOX);
//          o->down_box(FL_FLAT_BOX);
//          o->color(15);
//          o->selection_color(48);
//          pixmap_playbackwards.label(o);
//        }
      { Fl_Button* o = play_for_button = new Fl_Button(x+100, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	o->down_color(11);
        pixmap_playforwards.label(o);
	o->callback(cb_play_channel, (void *) &id);
      }
      { Fl_Button* o = pause_button = new Fl_Button(x+119, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	o->down_color(11);	
        pixmap_pause.label(o);
	o->callback(cb_pause_channel, (void *) &id);
      }
      { Fl_Button* o = stop_button = new Fl_Button(x+138, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	o->down_color(11);
        pixmap_stop.label(o);
	o->callback(cb_stop_channel, (void *) &id);
      }
      { Fl_Button* o = goforward_button = new Fl_Button(x+195, y+58, 14, 13, "@>|");
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(48);
        //pixmap_stepforward.label(o);
	o->labeltype(FL_SYMBOL_LABEL);
	o->labelcolor(46);
	o->callback(cb_set_channel_plus, (void *) &id);

      }
      { Fl_Slider* o = timeline_slider = new Fl_Slider(x+32, y+58, 158, 12);
        o->type(5);
        o->box(FL_FLAT_BOX);
        o->color(15);
	o->callback(cb_set_position, (void *) &id);
	o->slider_size(.14);
	//o->step(.001);
      }
      { Fl_Output* o = name = new Fl_Output(x+12, y+35, 198, 15);
        o->box(FL_FLAT_BOX);
        o->color(52);
	o->selection_color(52);
        o->labeltype(FL_NO_LABEL);
        o->textsize(11);
	o->textfont(1);
      }
      { Fl_Output* o = time = new Fl_Output(x+9, y+10, 60, 20);
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->labeltype(FL_NO_LABEL);
	o->value("00:00:00");
      }
      { Fl_Slider* o = volume_slider = new Fl_Slider(x+192, y+80, 10, 90, "vol"); //old x value:182
        o->type(4);
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(15);
        o->labelsize(9);
        o->minimum(1);
        o->maximum(0);
        o->value(1);
	o->slider_size(.14);
	o->step(.01);
	o->callback(cb_set_volume, (void *) &id);
      }
      { Fl_Slider* o = speed_slider = new Fl_Slider(x+208, y+80, 10, 90, "spd");
      o->type(4);
      o->box(FL_FLAT_BOX);
      o->color(15);
      o->labelsize(9);
      o->slider_size(.14);
      o->minimum(50);
      o->maximum(150);
      o->value(100);
      o->step(1);
      o->callback(cb_set_speed,(void *) &id);
      }
      { Fl_Select_Browser* o = playlist_browser = new Fl_Select_Browser(x+6, y+80, 183, 100);//old w value: 165
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(49);
        o->labeltype(FL_NO_LABEL);
        o->textsize(10);
	o->scrollbar_left();
        o->when(FL_WHEN_RELEASE);
        //Fl_Group::current()->resizable(o);
	o->callback(cb_set_channel, (void *) &id);
      }
      { Fl_Button* o = corner_button = new Fl_Button(x+207, y+2, 16, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        pixmap_dots3.label(o);
	o->callback(cb_browse_playlist, (void *)&id);
      }

      { Fl_Button* o = playmode_button = new Fl_Button(x+179, y+12, 17, 16, "play");
        o->box(FL_FLAT_BOX);
        o->labelsize(8);
	o->color(15);
	o->callback(cb_set_playmode, (void *) &id);
      }
//        { Fl_Output* o = kiloherz = new Fl_Output(x+90, y+54, 30, 12, "44.1");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
//        { Fl_Output* o = bitrate = new Fl_Output(x+113, y+54, 42, 12, "kbs");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
//        { Fl_Output* o = mono_stereo = new Fl_Output(x+151, y+54, 20, 12, "s");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
    o->end();
    //o->resizable(o);
  }
}

void GuiChannel::new_order(int x, int y)
{
  main_group->resize(x,y, 418, 85);
  stepback_button->resize(x+12, y+58, 14, 13);
  play_for_button->resize(x+100, y+13, 15, 15);
  pause_button->resize(x+114, y+12, 15, 16);
  stop_button->resize(x+130, y+13, 15, 15);
  goforward_button->resize(x+195, y+58, 14, 13);
  timeline_slider->resize(x+32, y+58, 158, 12);
  time->resize(x+9, y+10, 60, 20);
  name->resize(x+12, y+35, 198, 15);
  corner_button->resize(x+200, y+20, 16, 18);
  playmode_button->resize(x+179, y+12, 17, 16);
  
  volume_slider->resize(x+408, y+5, 10, 70);
  playlist_browser->resize(x+225, y, 180, 82);

}

==> MuSE-0.5.2.tar.gz: MuSE-0.5.2/gui_channel.cpp <==
#include "gui_channel.h"
#include "gui_callbacks.h"
#include "gui_pixmaps.h"
#include <iostream.h>

GuiChannel::GuiChannel(int x, int y, char *label, int z) {
  id =z;

  { Fl_Group* o = main_group = new Fl_Group(x, y, 225, 185, label);
      o->box(FL_UP_BOX);
      o->color(15);
      o->labeltype(FL_ENGRAVED_LABEL);
      o->labelsize(12);
      o->align(FL_ALIGN_TOP_LEFT);
      o->user_data((void*)(this));
      { Fl_Button* o = stepback_button = new Fl_Button(x+12, y+58, 14, 13, "@|<");
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(48);
	o->labeltype(FL_SYMBOL_LABEL);
	o->labelcolor(46);
	o->callback(cb_set_channel_minus, (void *) &id);
      }
//        { Fl_Button* o = play_rev_button = new Fl_Button(x+90, y+13, 15, 15);
//          o->box(FL_FLAT_BOX);
//          o->down_box(FL_FLAT_BOX);
//          o->color(15);
//          o->selection_color(48);
//          pixmap_playbackwards.label(o);
//        }
      { Fl_Button* o = play_for_button = new Fl_Button(x+100, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	//	o->down_color(15);
        pixmap_playforwards.label(o);
	o->callback(cb_play_channel, (void *) &id);
      }
      { Fl_Button* o = pause_button = new Fl_Button(x+119, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	//	o->down_color(15);	
        pixmap_pause.label(o);
	o->callback(cb_pause_channel, (void *) &id);
      }
      { Fl_Button* o = stop_button = new Fl_Button(x+138, y+13, 18, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_THIN_DOWN_BOX);
        o->color(15);
	//	o->down_color(15);
        pixmap_stop.label(o);
	o->callback(cb_stop_channel, (void *) &id);
      }
      { Fl_Button* o = goforward_button = new Fl_Button(x+195, y+58, 14, 13, "@>|");
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(48);
        //pixmap_stepforward.label(o);
	o->labeltype(FL_SYMBOL_LABEL);
	o->labelcolor(46);
	o->callback(cb_set_channel_plus, (void *) &id);

      }
      { Fl_Slider* o = timeline_slider = new Fl_Slider(x+32, y+58, 158, 12);
        o->type(5);
        o->box(FL_FLAT_BOX);
        o->color(15);
	o->callback(cb_set_position, (void *) &id);
	o->slider_size(.14);
	//o->step(.001);
      }
      { Fl_Output* o = name = new Fl_Output(x+12, y+35, 198, 15);
        o->box(FL_FLAT_BOX);
        o->color(52);
	o->selection_color(52);
        o->labeltype(FL_NO_LABEL);
        o->textsize(11);
	o->textfont(1);
      }
      { Fl_Output* o = time = new Fl_Output(x+9, y+10, 60, 20);
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->labeltype(FL_NO_LABEL);
	o->value("00:00:00");
      }
      { Fl_Slider* o = volume_slider = new Fl_Slider(x+200, y+80, 10, 90, "vol"); //old x value:182
        o->type(4);
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(15);
        o->labelsize(9);
        o->minimum(1);
        o->maximum(0);
        o->value(1);
	o->slider_size(.14);
	o->step(.01);
	o->callback(cb_set_volume, (void *) &id);
      }
      /*
      { Fl_Slider* o = speed_slider = new Fl_Slider(x+208, y+80, 10, 90, "spd");
      o->type(4);
      o->box(FL_FLAT_BOX);
      o->color(15);
      o->labelsize(9);
      o->slider_size(.14);
      o->minimum(50);
      o->maximum(150);
      o->value(100);
      o->step(1);
      o->callback(cb_set_speed,(void *) &id);
      }
      */
      { Fl_Select_Browser* o = playlist_browser = new Fl_Select_Browser(x+6, y+80, 183, 100);//old w value: 165
        o->box(FL_FLAT_BOX);
        o->color(15);
        o->selection_color(49);
        o->labeltype(FL_NO_LABEL);
        o->textsize(10);
	//	o->scrollbar_left();
        o->when(FL_WHEN_RELEASE);
        //Fl_Group::current()->resizable(o);
	o->callback(cb_set_channel, (void *) &id);
      }
      { Fl_Button* o = corner_button = new Fl_Button(x+207, y+2, 16, 18);
        o->box(FL_FLAT_BOX);
        o->down_box(FL_FLAT_BOX);
        o->color(15);
        pixmap_dots3.label(o);
	o->callback(cb_browse_playlist, (void *)&id);
      }

      { Fl_Button* o = playmode_button = new Fl_Button(x+179, y+12, 17, 16, "play");
        o->box(FL_FLAT_BOX);
        o->labelsize(8);
	o->color(15);
	o->callback(cb_set_playmode, (void *) &id);
      }
//        { Fl_Output* o = kiloherz = new Fl_Output(x+90, y+54, 30, 12, "44.1");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
//        { Fl_Output* o = bitrate = new Fl_Output(x+113, y+54, 42, 12, "kbs");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
//        { Fl_Output* o = mono_stereo = new Fl_Output(x+151, y+54, 20, 12, "s");
//          o->box(FL_FLAT_BOX);
//          o->color(15);
//          o->labeltype(FL_NO_LABEL);
//          o->textsize(8);
//        }
    o->end();
    //o->resizable(o);
  }
}

void GuiChannel::new_order(int x, int y)
{
  main_group->resize(x,y, 418, 85);
  stepback_button->resize(x+12, y+58, 14, 13);
  play_for_button->resize(x+100, y+13, 15, 15);
  pause_button->resize(x+114, y+12, 15, 16);
  stop_button->resize(x+130, y+13, 15, 15);
  goforward_button->resize(x+195, y+58, 14, 13);
  timeline_slider->resize(x+32, y+58, 158, 12);
  time->resize(x+9, y+10, 60, 20);
  name->resize(x+12, y+35, 198, 15);
  corner_button->resize(x+200, y+20, 16, 18);
  playmode_button->resize(x+179, y+12, 17, 16);
  
  volume_slider->resize(x+408, y+5, 10, 70);
  playlist_browser->resize(x+225, y, 180, 82);

}
